@@ -38,8 +38,8 @@ The S3 bucket is configured as below
 * enabled versioning of objects
 * enabled encryption using an S3 managed Key
 * disallowing public access
-* A lifecycle configuration for the archived repositories. They transistion
-  through different storage classes
+* A lifecycle configuration for the archived repositories. They and their
+  versions transistion through different storage classes
 
   * Infrequent Access after 30 days
   * Glacier after 90 days
@@ -53,6 +53,10 @@ The CodeBuild projects are configured as below
 
   * Configurable retention period. Default is one month.
   * Encryption using customer-managed KMS key
+* Schedule based execution.
+
+  * The default schedule is one week and can be overriden as part of the backup
+    configuration.
 
 ## Prerequisites
 
@@ -73,7 +77,7 @@ aws secretsmanager create-secret --name repository_archiver --description "Secre
   ```javascript
   "dependencies": {
     [...],
-    "azure-devops-repository-archiver": "0.0.23",
+    "azure-devops-repository-archiver": "1.4.0",
   },
   ```
 * Per `BackupConfiguration` a secret containing the Azure DevOps PAT needs to be
@@ -156,6 +160,7 @@ from typeguard import check_type
 
 from ._jsii import *
 
+import aws_cdk.aws_events as _aws_cdk_aws_events_ceddda9d
 import aws_cdk.aws_kms as _aws_cdk_aws_kms_ceddda9d
 import aws_cdk.aws_logs as _aws_cdk_aws_logs_ceddda9d
 import aws_cdk.aws_s3 as _aws_cdk_aws_s3_ceddda9d
@@ -182,7 +187,7 @@ class Archiver(
         :param id: -
         :param backup_configurations: Contains details on the git repositories to be backed up.
         :param notification_events: S3 events that will trigger a message to the SNS topic. For example "EventType.LIFECYCLE_EXPIRATION" or "EventType.OBJECT_CREATED".
-        :param retention_days: Number of days to keep the Cloudwatch logs. Default: RetentionDays.ONE_MONTH
+        :param retention_days: The number of days to keep the Cloudwatch logs. Default: RetentionDays.ONE_MONTH
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__59b1d445ea6a4ea2b344c5e83eb14b7e5d57e243d55dbad607605e1e2e63c1b5)
@@ -297,7 +302,7 @@ class ArchiverProperties:
         '''
         :param backup_configurations: Contains details on the git repositories to be backed up.
         :param notification_events: S3 events that will trigger a message to the SNS topic. For example "EventType.LIFECYCLE_EXPIRATION" or "EventType.OBJECT_CREATED".
-        :param retention_days: Number of days to keep the Cloudwatch logs. Default: RetentionDays.ONE_MONTH
+        :param retention_days: The number of days to keep the Cloudwatch logs. Default: RetentionDays.ONE_MONTH
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__bfaace2f4df93a4fab67f960625a0f4057a1c4ba23833a63c0ffee999a9a724d)
@@ -342,7 +347,7 @@ class ArchiverProperties:
     def retention_days(
         self,
     ) -> typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays]:
-        '''Number of days to keep the Cloudwatch logs.
+        '''The number of days to keep the Cloudwatch logs.
 
         :default: RetentionDays.ONE_MONTH
 
@@ -372,6 +377,7 @@ class ArchiverProperties:
         "project_name": "projectName",
         "repository_names": "repositoryNames",
         "secret_arn": "secretArn",
+        "schedule": "schedule",
     },
 )
 class BackupConfiguration:
@@ -382,12 +388,18 @@ class BackupConfiguration:
         project_name: builtins.str,
         repository_names: typing.Sequence[builtins.str],
         secret_arn: builtins.str,
+        schedule: typing.Optional[_aws_cdk_aws_events_ceddda9d.Schedule] = None,
     ) -> None:
-        '''
+        '''A backup configuration defining - the repositories to backup, and   - the backup interval All repositories that are part of a backup configuration are belonging to the same Azure DevOps organization and project.
+
         :param organization_name: The name of the Azure DevOps organization.
         :param project_name: The name of the Azure DevOps project.
         :param repository_names: The names of the git repositories to backup.
         :param secret_arn: ARN of the secret containing the token for accessing the git repositories of the Azure DevOps organization.
+        :param schedule: The schedule allows to define the frequency of backups. If not defined, a weekly backup is configured. Default: Schedule.expression('cron(0 0 ? * 1 *)')
+
+        :export: true
+        :interface: BackupConfiguration
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__73a3057dbc68fd09362014a7e60186c3a5a6831c5a676af4878318e4f1323881)
@@ -395,12 +407,15 @@ class BackupConfiguration:
             check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
             check_type(argname="argument repository_names", value=repository_names, expected_type=type_hints["repository_names"])
             check_type(argname="argument secret_arn", value=secret_arn, expected_type=type_hints["secret_arn"])
+            check_type(argname="argument schedule", value=schedule, expected_type=type_hints["schedule"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "organization_name": organization_name,
             "project_name": project_name,
             "repository_names": repository_names,
             "secret_arn": secret_arn,
         }
+        if schedule is not None:
+            self._values["schedule"] = schedule
 
     @builtins.property
     def organization_name(self) -> builtins.str:
@@ -446,6 +461,20 @@ class BackupConfiguration:
         assert result is not None, "Required property 'secret_arn' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def schedule(self) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.Schedule]:
+        '''The schedule allows to define the frequency of backups.
+
+        If not defined, a weekly backup is configured.
+
+        :default: Schedule.expression('cron(0 0 ? * 1 *)')
+
+        :memberof: BackupConfiguration
+        :type: {Schedule}
+        '''
+        result = self._values.get("schedule")
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.Schedule], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -522,6 +551,7 @@ def _typecheckingstub__73a3057dbc68fd09362014a7e60186c3a5a6831c5a676af4878318e4f
     project_name: builtins.str,
     repository_names: typing.Sequence[builtins.str],
     secret_arn: builtins.str,
+    schedule: typing.Optional[_aws_cdk_aws_events_ceddda9d.Schedule] = None,
 ) -> None:
     """Type checking stubs"""
     pass
